@@ -18,3 +18,9 @@ guardExecution <- function(yourExpression_ex, instrumentWarnings_b = TRUE) {
              error = function(e) e)
   }
 }
+
+buildIdentityList <- function(entries_s) {
+  d <- toupper(entries_s)
+  names(d) <- gsub('[^A-Z0-9_]', '', d, perl = TRUE)
+  as.list(d)
+}
